﻿using System;
using System.ComponentModel;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;
using System.Windows.Media;
using Infragistics.Controls.Editors;

namespace MyFirstWPFProgram.Prototypes
{
    /// <summary>
    /// Interaction logic for SolutionItem.xaml
    /// </summary>
    public partial class SolutionItem
    {
        private Point _startPoint;
        public SolutionItemProperties Properties = SolutionItemProperties.Instance;
        public SolutionItemLocalProperties LocalProperties = new SolutionItemLocalProperties();

        public SolutionItem()
        {
            InitializeComponent();
            this.DataContext = LocalProperties;
            this.pnlCarouselList.DataContext = Properties;
        }


        private void UIElement_OnPreviewMouseLeftButtonDown(object sender, MouseButtonEventArgs e)
        {
            _startPoint = e.GetPosition(null);
        }

        private void UIElement_OnMouseMove(object sender, MouseEventArgs e)
        {
            // Get the current mouse position
            Point mousePos = e.GetPosition(null);
            Vector diff = _startPoint - mousePos;

            if (e.LeftButton == MouseButtonState.Pressed &&
                (Math.Abs(diff.X) > 0 ||
                Math.Abs(diff.Y) > 0))
            {
                //var image = (Image)sender;
                var item = (ItemControl)sender;

                // Initialize the drag & drop operation
                var dragData = new DataObject("myFormat", item);
                DragDrop.DoDragDrop(item, dragData, DragDropEffects.All);
            }
        }

        private void UIElement_OnDragEnter(object sender, DragEventArgs e)
        {
            if (!e.Data.GetDataPresent("myFormat") ||
        sender == e.Source)
            {
                e.Effects = DragDropEffects.None;
            }
        }

        private void UIElement_OnDrop(object sender, DragEventArgs e)
        {
            if (e.Data.GetDataPresent("myFormat"))
            {
                var image = e.Data.GetData("myFormat") as Image;
                if (image == null) return;

                var itemData = new ItemData()
                    {
                        ObjectName = image.Name,
                        Property1 = "Min: -50",
                        Property2 = "Max: 50",
                        ViewName = "A2",
                        DisplayImage = {Source = image.Source.Clone()},
                        ParentControl = CarouselPanel
                    };
                var itemControl = new ItemControl(itemData);
                CarouselPanel.Items.Add(itemControl);
                //wrapPanel.Children.Add(new ItemControl(itemData));
            }
        }

        private void Settings_OnClick(object sender, RoutedEventArgs e)
        {
            MessageBox.Show("Settings", "diUX", MessageBoxButton.OK);
        }

        private void Delete_OnClick(object sender, RoutedEventArgs e)
        {
            MessageBox.Show("Delete", "diUX", MessageBoxButton.OK);
        }

        private void RemoveAllRows_OnClick(object sender, RoutedEventArgs e)
        {
            MessageBox.Show("Remove all rows.", "diUX", MessageBoxButton.OK);
        }

        private void ClearRow_OnClick(object sender, RoutedEventArgs e)
        {
            MessageBox.Show("Clear row.", "diUX", MessageBoxButton.OK);
        }

        private void Pin_OnClick(object sender, RoutedEventArgs e)
        {
            MessageBox.Show("Pin item.", "diUX", MessageBoxButton.OK);}

        private void Remove_OnClick(object sender, RoutedEventArgs e)
        {
            MessageBox.Show("Remove item", "diUX", MessageBoxButton.OK);
        }

        private void ClearObjects_OnClick(object sender, RoutedEventArgs e)
        {
            MessageBox.Show("Clear objects", "diUX", MessageBoxButton.OK);
        }

        private void ClearAttributes_OnClick(object sender, RoutedEventArgs e)
        {
            MessageBox.Show("Clear attributes", "diUX", MessageBoxButton.OK);
        }

        private void RowDeleteClick(object sender, RoutedEventArgs e)
        {
            
        }

        private void SearchClick(object sender, RoutedEventArgs e)
        {
                
        }

        private void ColorChanged(object sender, SelectedColorChangedEventArgs e)
        {
            if (e.NewColor != null) this.LocalProperties.BackgroundColor = new SolidColorBrush((Color) e.NewColor);
        }
    }

    public class SolutionItemProperties : INotifyPropertyChanged
    {
        public double NumberOfItems
        {
            get { return _numberOfItems; }
            set
            {
                _numberOfItems = value;
                OnPropertyChanged("NumberOfItems");
            }
        }

        public double Width
        {
            get { return _width; }
            set
            {
                _width = value;
                OnPropertyChanged("Width");
            }
        }
        
        private static SolutionItemProperties _instance;
        private double _numberOfItems;
        private double _width;

        public static SolutionItemProperties Instance
        {
            get { return _instance ?? (_instance = new SolutionItemProperties()); }
        }

        private SolutionItemProperties()
        {
            NumberOfItems = 4;
            Width = 420;
        }

        public event PropertyChangedEventHandler PropertyChanged;

        // Create the OnPropertyChanged method to raise the event 
        protected void OnPropertyChanged(string name)
        {
            PropertyChangedEventHandler handler = PropertyChanged;
            if (handler != null)
            {
                handler(this, new PropertyChangedEventArgs(name));
            }
        }
    }

    public class SolutionItemLocalProperties : INotifyPropertyChanged
    {
        public Brush BackgroundColor
        {
            get { return _backgroundColor; }
            set
            {
                _backgroundColor = value;
                OnPropertyChanged("BackgroundColor");
            }
        }

        private Brush _backgroundColor;
        
        public SolutionItemLocalProperties()
        {
            BackgroundColor = new SolidColorBrush(Colors.WhiteSmoke);
        }

        public event PropertyChangedEventHandler PropertyChanged;

        // Create the OnPropertyChanged method to raise the event 
        protected void OnPropertyChanged(string name)
        {
            PropertyChangedEventHandler handler = PropertyChanged;
            if (handler != null)
            {
                handler(this, new PropertyChangedEventArgs(name));
            }
        }
    }
}
